==> umbrello-20.04.2.tar.xz: umbrello-20.04.2/lib/kdev4-php/testprovider/kdevphpunitprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Finds and runs PHPUnit tests.
Comment[ca]=Cerca i executa les proves del PHPUnit.
Comment[ca@valencia]=Cerca i executa les proves del PHPUnit.
Comment[cs]=Hledá a spouští testy PHPUnit.
Comment[da]=Finder og kører PHPUnit-test.
Comment[de]=Sucht und führt PHPUnit-Tests aus.
Comment[el]=Βρίσκει και εκτελεί PHPUnit tests.
Comment[en_GB]=Finds and runs PHPUnit tests.
Comment[es]=Encuentra y ejecuta pruebas PHPUnit.
Comment[et]=PHPUnit testide otsimine ja käivitamine.
Comment[fi]=Etsii ja suorittaa PHPUnit-testejä.
Comment[fr]=Trouve et exécute des tests « PHPUnit ».
Comment[gl]=Atopa e executa probas de PHPUnit.
Comment[it]=Trova ed esegue i test PHPUnit
Comment[ko]=PHPUnit 테스트를 찾아서 실행합니다.
Comment[nb]=Finner og kjører PHPUnit-tester.
Comment[nl]=Testen van PHPUnit vinden en uitvoeren.
Comment[nn]=Finn og køyr PHPUnit-testar.
Comment[pl]=Znajduje i uruchamia testy PHPUnit.
Comment[pt]=Procura e executa os testes do PHPUnit.
Comment[pt_BR]=Procura e executa os testes do PHPUnit.
Comment[sk]=Nájde a spustí PHPUnit testy.
Comment[sl]=Najde in zažene preizkuse PHPUnit
Comment[sv]=Söker efter och kör PHPUnit-tester.
Comment[tr]=PHPUnit testlerini bulur ve çalıştırır.
Comment[uk]=Пошук і запуск перевірок PHPUnit.
Comment[x-test]=xxFinds and runs PHPUnit tests.xx
Comment[zh_CN]=查找并运行 PHPUnit 测试
Comment[zh_TW]=尋找、執行 PHPUnit 測試。
Name=PHPUnit Integration
Name[ca]=Integració del PHPUnit
Name[ca@valencia]=Integració del PHPUnit
Name[cs]=Integrace PHPUnit
Name[da]=PHPUnit-integration
Name[de]=PHPUnit-Integration
Name[el]=Ενσωμάτωση PHPUnit
Name[en_GB]=PHPUnit Integration
Name[es]=Integración de PHPUnit
Name[et]=PHPUnitiga lõimimine
Name[fi]=PHPUnit-integrointi
Name[fr]=Intégration de « PHPUnit »
Name[gl]=Integración con PHPUnit
Name[it]=Integrazione PHPUnit
Name[ko]=PHPUnit 통합
Name[nb]=PHPUnit-integrering
Name[nl]=Integratie van PHPUnit
Name[nn]=PHPUnit-integrering
Name[pl]=Integracja PHPUnit
Name[pt]=Integração com o PHPUnit
Name[pt_BR]=Integração com o PHPUnit
Name[sk]=Integrácia PHPUnit
Name[sl]=Podpora PHPUnit
Name[sv]=Integrering av PHPUnit
Name[tr]=PHPUnit Bütünleşmesi
Name[uk]=Інтеграція PHPUnit
Name[x-test]=xxPHPUnit Integrationxx
Name[zh_CN]=PHPUnit 集成
Name[zh_TW]=PHPUnit 積分
GenericName=PHPUnit Integration
GenericName[ca]=Integració del PHPUnit
GenericName[ca@valencia]=Integració del PHPUnit
GenericName[cs]=Integrace PHPUnit
GenericName[da]=PHPUnit-integration
GenericName[de]=PHPUnit-Integration
GenericName[el]=Ενσωμάτωση PHPUnit
GenericName[en_GB]=PHPUnit Integration
GenericName[es]=Integración de PHPUnit
GenericName[et]=PHPUnitiga lõimimine
GenericName[fi]=PHPUnit-integrointi
GenericName[fr]=Intégration de « PHPUnit »
GenericName[gl]=Integración con PHPUnit
GenericName[it]=Integrazione PHPUnit
GenericName[ko]=PHPUnit 통합
GenericName[nb]=PHPUnit-integrering
GenericName[nl]=Integratie van PHPUnit
GenericName[nn]=PHPUnit-integrering
GenericName[pl]=Integracja PHPUnit
GenericName[pt]=Integração com o PHPUnit
GenericName[pt_BR]=Integração com o PHPUnit
GenericName[sk]=Integrácia PHPUnit
GenericName[sl]=Podpora PHPUnit
GenericName[sv]=Integrering av PHPUnit
GenericName[tr]=PHPUnit Bütünleşmesi
GenericName[uk]=Інтеграція PHPUnit
GenericName[x-test]=xxPHPUnit Integrationxx
GenericName[zh_CN]=PHPUnit 集成
GenericName[zh_TW]=PHPUnit 積分
Icon=php
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevphpunitprovider
X-KDE-PluginInfo-Name=kdevphpunitprovider
X-KDE-PluginInfo-Author=Miha Čančula
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Testing
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ITestProvider
X-KDevelop-Mode=NoGUI

==> umbrello-20.07.90.tar.xz: umbrello-20.07.90/lib/kdev4-php/testprovider/kdevphpunitprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Finds and runs PHPUnit tests.
Comment[ca]=Cerca i executa les proves del PHPUnit.
Comment[ca@valencia]=Cerca i executa les proves del PHPUnit.
Comment[cs]=Hledá a spouští testy PHPUnit.
Comment[da]=Finder og kører PHPUnit-test.
Comment[de]=Sucht und führt PHPUnit-Tests aus.
Comment[el]=Βρίσκει και εκτελεί PHPUnit tests.
Comment[en_GB]=Finds and runs PHPUnit tests.
Comment[es]=Encuentra y ejecuta pruebas PHPUnit.
Comment[et]=PHPUnit testide otsimine ja käivitamine.
Comment[fi]=Etsii ja suorittaa PHPUnit-testejä.
Comment[fr]=Trouve et exécute des tests « PHPUnit ».
Comment[gl]=Atopa e executa probas de PHPUnit.
Comment[it]=Trova ed esegue i test PHPUnit
Comment[ko]=PHPUnit 테스트를 찾아서 실행합니다.
Comment[nb]=Finner og kjører PHPUnit-tester.
Comment[nl]=Testen van PHPUnit vinden en uitvoeren.
Comment[nn]=Finn og køyr PHPUnit-testar.
Comment[pl]=Znajduje i uruchamia testy PHPUnit.
Comment[pt]=Procura e executa os testes do PHPUnit.
Comment[pt_BR]=Procura e executa os testes do PHPUnit.
Comment[sk]=Nájde a spustí PHPUnit testy.
Comment[sl]=Najde in zažene preizkuse PHPUnit.
Comment[sv]=Söker efter och kör PHPUnit-tester.
Comment[tr]=PHPUnit testlerini bulur ve çalıştırır.
Comment[uk]=Пошук і запуск перевірок PHPUnit.
Comment[x-test]=xxFinds and runs PHPUnit tests.xx
Comment[zh_CN]=查找并运行 PHPUnit 测试
Comment[zh_TW]=尋找、執行 PHPUnit 測試。
Name=PHPUnit Integration
Name[ca]=Integració del PHPUnit
Name[ca@valencia]=Integració del PHPUnit
Name[cs]=Integrace PHPUnit
Name[da]=PHPUnit-integration
Name[de]=PHPUnit-Integration
Name[el]=Ενσωμάτωση PHPUnit
Name[en_GB]=PHPUnit Integration
Name[es]=Integración de PHPUnit
Name[et]=PHPUnitiga lõimimine
Name[fi]=PHPUnit-integrointi
Name[fr]=Intégration de « PHPUnit »
Name[gl]=Integración con PHPUnit
Name[it]=Integrazione PHPUnit
Name[ko]=PHPUnit 통합
Name[nb]=PHPUnit-integrering
Name[nl]=Integratie van PHPUnit
Name[nn]=PHPUnit-integrering
Name[pl]=Integracja PHPUnit
Name[pt]=Integração com o PHPUnit
Name[pt_BR]=Integração com o PHPUnit
Name[sk]=Integrácia PHPUnit
Name[sl]=Podpora PHPUnit
Name[sv]=Integrering av PHPUnit
Name[tr]=PHPUnit Bütünleşmesi
Name[uk]=Інтеграція PHPUnit
Name[x-test]=xxPHPUnit Integrationxx
Name[zh_CN]=PHPUnit 集成
Name[zh_TW]=PHPUnit 積分
GenericName=PHPUnit Integration
GenericName[ca]=Integració del PHPUnit
GenericName[ca@valencia]=Integració del PHPUnit
GenericName[cs]=Integrace PHPUnit
GenericName[da]=PHPUnit-integration
GenericName[de]=PHPUnit-Integration
GenericName[el]=Ενσωμάτωση PHPUnit
GenericName[en_GB]=PHPUnit Integration
GenericName[es]=Integración de PHPUnit
GenericName[et]=PHPUnitiga lõimimine
GenericName[fi]=PHPUnit-integrointi
GenericName[fr]=Intégration de « PHPUnit »
GenericName[gl]=Integración con PHPUnit
GenericName[it]=Integrazione PHPUnit
GenericName[ko]=PHPUnit 통합
GenericName[nb]=PHPUnit-integrering
GenericName[nl]=Integratie van PHPUnit
GenericName[nn]=PHPUnit-integrering
GenericName[pl]=Integracja PHPUnit
GenericName[pt]=Integração com o PHPUnit
GenericName[pt_BR]=Integração com o PHPUnit
GenericName[sk]=Integrácia PHPUnit
GenericName[sl]=Podpora PHPUnit
GenericName[sv]=Integrering av PHPUnit
GenericName[tr]=PHPUnit Bütünleşmesi
GenericName[uk]=Інтеграція PHPUnit
GenericName[x-test]=xxPHPUnit Integrationxx
GenericName[zh_CN]=PHPUnit 集成
GenericName[zh_TW]=PHPUnit 積分
Icon=php
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevphpunitprovider
X-KDE-PluginInfo-Name=kdevphpunitprovider
X-KDE-PluginInfo-Author=Miha Čančula
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Testing
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ITestProvider
X-KDevelop-Mode=NoGUI
